@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Dist::Zilla::PluginBundle::MITHALDU;
-our $VERSION = '1.150521'; # VERSION
+our $VERSION = '1.150590'; # VERSION
 
 # Dependencies
 use autodie 2.00;
@@ -29,7 +29,6 @@ use Dist::Zilla::Plugin::MetaNoIndex ();
 use Dist::Zilla::Plugin::MetaProvides::Package 1.11044404 ();
 use Dist::Zilla::Plugin::MinimumPerl ();
 use Dist::Zilla::Plugin::OurPkgVersion 0.001008 ();
-use Dist::Zilla::Plugin::Test::PodSpelling 2.001002 ();
 use Dist::Zilla::Plugin::Test::Perl::Critic ();
 use Dist::Zilla::Plugin::PodWeaver ();
 use Dist::Zilla::Plugin::Test::Portability ();
@@ -47,16 +46,7 @@ use Dist::Zilla::App::Command::cover; # this is just here for the prereqs to
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
-sub mvp_multivalue_args { qw/stopwords gitignore exclude_match/ }
-
-has stopwords => (
-  is      => 'ro',
-  isa     => 'ArrayRef',
-  lazy    => 1,
-  default => sub {
-    exists $_[0]->payload->{stopwords} ? $_[0]->payload->{stopwords} : []
-  },
-);
+sub mvp_multivalue_args { qw/gitignore exclude_match skip_prereq/ }
 
 has fake_release => (
   is      => 'ro',
@@ -71,12 +61,6 @@ has no_critic => (
   default => 0,
 );
 
-has no_spellcheck => (
-  is      => 'ro',
-  isa     => 'Bool',
-  default => 0,
-);
-
 has is_task => (
   is      => 'ro',
   isa     => 'Bool',
@@ -149,6 +133,19 @@ has exclude_match => (
   },
 );
 
+has skip_prereq => (
+  is      => 'ro',
+  isa     => 'ArrayRef',
+  lazy    => 1,
+  default => sub {
+    my ($self) = @_;
+    my $payload = $_[0]->payload;
+    return [] if !exists $payload->{skip_prereq};
+    my $match = $payload->{skip_prereq};
+    return ref $match ? $match : [$match];
+  },
+);
+
 has prune_except => (
   is      => 'ro',
   isa     => 'ArrayRef',
@@ -200,7 +197,7 @@ sub configure {
   my $is_release = grep /^release$/, @ARGV;
   $version_provider = [ 'AutoVersion' => { major => $self->major_version } ] if $is_release;
 
-  my @generated_files = qw( META.json Makefile.PL cpanfile README );
+  my @generated_files = qw( META.json Makefile.PL cpanfile README.pod );
   my @on_release_files = ( qw/dist.ini Changes/, @generated_files );
 
   my @plugins = (
@@ -225,14 +222,19 @@ sub configure {
     ),
 
   # generated distribution files
-    'Pod2Readme',
+    'ReadmeFromPod',
     'License',            # core
+    [ ReadmeAnyFromPod => { # generate in root for github, etc.
+        type => 'pod',
+        filename => 'README.pod',
+        location => 'root',
+      }
+    ],
 
   # generated t/ tests
     [ 'Test::Compile' => { fake_home => 1 } ],
 
   # generated xt/ tests
-    [ 'Test::PodSpelling' => (scalar @{$self->stopwords}) ? ({ stopwords => $self->stopwords }) : () ],
     'Test::Perl::Critic',
     'MetaTests',          # core
     'PodSyntaxTests',     # core
@@ -242,7 +244,7 @@ sub configure {
 
   # metadata
     'MinimumPerl',
-    ( $self->auto_prereq ? 'AutoPrereqs' : () ),
+    ( $self->auto_prereq ? ['AutoPrereqs' => (scalar @{$self->skip_prereq}) ? ({ skip => $self->skip_prereq }) : ()] : () ),
     'CPANFile',
     [ GithubMeta => { remote => $self->git_remote, ( $is_release ? () : @{$old_github} ) } ],
     [ MetaNoIndex => {
@@ -333,7 +335,7 @@ Dist::Zilla::PluginBundle::MITHALDU - Dist::Zilla configuration the way MITHALDU
 
 =head1 VERSION
 
-version 1.150521
+version 1.150590
 
 =head1 SYNOPSIS
 
@@ -401,7 +403,6 @@ following dist.ini:
    fake_home = 1       ; fakes $ENV{HOME} just in case
  
    ; xt tests
-   [Test::PodSpelling] ; xt/author/pod-spell.t
    [Test::Perl::Critic]; xt/author/critic.t
    [MetaTests]         ; xt/release/meta-yaml.t
    [PodSyntaxTests]    ; xt/release/pod-syntax.t
@@ -475,9 +476,6 @@ following dist.ini:
    [Git::Push]         ; push repo to remote
    push_to = origin
 
-=for stopwords autoprereq mithaldu fakerelease pluginbundle podweaver
-taskweaver uploadtocpan dist ini
-
 =for Pod::Coverage configure mvp_multivalue_args old_meta
 
 =head1 USAGE
@@ -517,18 +515,10 @@ C<<< weaver_config >>> -- specifies a Pod::Weaver bundle.  Defaults to @MITHALDU
 
 =item *
 
-C<<< stopwords >>> -- add stopword for Test::PodSpelling (can be repeated)
-
-=item *
-
 C<<< no_critic >>> -- omit Test::Perl::Critic tests
 
 =item *
 
-C<<< no_spellcheck >>> -- omit Test::PodSpelling tests
-
-=item *
-
 C<<< gitignore >>> -- adds entries to be added to .gitignore (can be repeated)
 
 =item *
